<?php
/**
 * Plugin Name: VEB Analytics Integration
 * Description: Add a VEB Analytics tracking pixel to your WordPress site. Intuitive, Accurate, Privacy-focused website analytics.
 * Version: 1.2
 * Author: VEB Analytics
 * Author URI: https://vebanalytics.com/?utm_source=wp-plugins&utm_campaign=author-uri&utm_medium=wp-dash
 */

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

// Add a new settings page
add_action('admin_menu', 'veb_analytics_add_settings_page');
function veb_analytics_add_settings_page() {
    add_options_page(
        'VEB Analytics Settings',
        'VEB Analytics',
        'manage_options',
        'veb-analytics-settings',
        'veb_analytics_render_settings_page'
    );
}

// Render the settings page
function veb_analytics_render_settings_page() {
    ?>
    <div class="wrap">
        <h1>VEB Analytics Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('veb_analytics_settings_group');
            do_settings_sections('veb_analytics_settings');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

// Register settings
add_action('admin_init', 'veb_analytics_register_settings');
function veb_analytics_register_settings() {
    register_setting('veb_analytics_settings_group', 'veb_analytics_tracking_id');

    add_settings_section(
        'veb_analytics_main_section',
        'VEB Analytics Configuration',
        null,
        'veb_analytics_settings'
    );

    add_settings_field(
        'veb_analytics_tracking_id_field',
        'Tracking ID',
        'veb_analytics_tracking_id_field_callback',
        'veb_analytics_settings',
        'veb_analytics_main_section'
    );
}

function veb_analytics_tracking_id_field_callback() {
    $tracking_id = get_option('veb_analytics_tracking_id');
    echo '<input type="text" name="veb_analytics_tracking_id" value="' . esc_attr($tracking_id) . '" placeholder="Enter your tracking ID" />';
}

// Add the JS snippet to the head of the site
add_action('wp_head', 'veb_analytics_add_js_to_head');
function veb_analytics_add_js_to_head() {
    $tracking_id = get_option('veb_analytics_tracking_id');
    if ($tracking_id) {
        echo "<!-- Pixel Code - https://vebanalytics.com/ -->
<script defer src=\"https://vebanalytics.com/pixel/" . esc_js($tracking_id) . "\"></script>
<!-- END Pixel Code -->";
    }
}

// Add settings link to the plugin actions
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'veb_analytics_add_settings_link');
function veb_analytics_add_settings_link($links) {
    $settings_link = '<a href="options-general.php?page=veb-analytics-settings" target="_blank">Settings</a>';
    array_unshift($links, $settings_link);
    return $links;
}
